<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>À propos de KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX est distribué selon les conditions de la GNU General Public License (GPL) version 2 ou (à votre choix) version 3.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Utilise :</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-Type - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Impossible de trouver une entrée qui corresponde au titre de la fenêtre :</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Séquence</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Séquence par défaut</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-Type - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Choisissez un champ pour Auto-Type :</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Entrez un mot de passe :</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Confirmez le mot de passe :</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Fichier-clé</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Naviguer</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Créer</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Fichiers-clés</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Créer un fichier-clé...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Impossible de créer un fichier-clé :</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Choisir un fichier-clé</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Voulez-vous vraiment utiliser une chaîne vide comme mot de passe ?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Les mots de passe ne sont pas identiques.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Échec de définition du fichier-clé</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Impossible de définir %1 comme fichier-clé :
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Entrez la clé maître</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Fichier-clé :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Naviguer</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Impossible d&apos;ouvrir le fichier-clé</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Fichiers-clés</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Choisissez un fichier-clé</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Réparer la base de données</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Impossible d&apos;ouvrir le fichier-clé</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>La base de données s&apos;est bien ouverte. Aucune action à effectuer.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>La base de données a correctement été réparée.
Vous pouvez maintenant la sauvegarder.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Impossible de réparer la base de données.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Nom de la base de données :</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Description de la base de données :</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Passes de transformation :</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Nom d&apos;utilisateur par défaut :</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Utiliser la corbeille :</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Base de référence</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Nombre max. d&apos;éléments dans l&apos;historique :</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Taille max. de l&apos;historique :</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Racine</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Base de données Keepass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Ouvrir la base de données</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Fichier introuvable !</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Ouvrir une base de données KeePass 1</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>Base de données Keepass 1</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Fermer ?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; a été modifié.
Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture de la base de données.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Enregistrer comme nouvelle base de données</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nouvelle base de données</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>verrouillée</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>La base de données que vous essayez d&apos;ouvrir est verrouillée par une autre instance de KeePassX.
Voulez-vous quand même l&apos;ouvrir ? Dans ce cas, elle sera ouverte en lecture seule.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Verrouiller la base de données</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Impossible de verrouiller la base de données lors de modifications.
Cliquez sur Annuler pour finir vos modifications ou abandonnez-les.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Cette base de données n&apos;a pas encore été sauvegardée.
Vous devez la sauvegarder ou annuler son verrouillage.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>La base de données a été modifiée.
Voulez-vous l&apos;enregistrer avant de la verrouiller ?
Autrement, vos modifications seront perdues.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; est en mode édition.
Ignorer les changements et fermer ?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Exporter la base de données au format CSV</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>Fichier CSV</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Échec de l&apos;écriture du fichier CSV.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>La base de données que vous essayez de sauvegarder a été verrouillée par une autre instance de KeePassX.
Voulez-vous quand même la sauvegarder ?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Changer la clé maître</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Supprimer l&apos;entrée ?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Voulez-vous supprimer l&apos;entrée &quot;%1&quot; définitivement ?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Supprimer les entrées ?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Voulez-vous supprimer &quot;%1&quot; entrées définitivement ?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Déplacer les entrées vers la corbeille ?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Voulez-vous déplacer %n entrée(s) vers la corbeille ?</numerusform><numerusform>Voulez-vous déplacer %n entrée(s) vers la corbeille ?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Supprimer le groupe ?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Voulez-vous supprimer le groupe &quot;%1&quot; définitivement ?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Groupe actif</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Remplissage automatique</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Historique de l&apos;entrée</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Ajouter une entrée</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Modifier l&apos;entrée</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Les mots de passe ne sont pas identiques.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nouvel attribut</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Choisissez un fichier</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Enregistrer le fichier attaché</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Impossible d&apos;enregistrer le fichier attaché :
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n semaine(s)</numerusform><numerusform>%n semaine(s)</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n mois</numerusform><numerusform>%n mois</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 an</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Attributs supplémentaires</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Activer le remplissage automatique pour cette entrée</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Utiliser la séquence de remplissage automatique par défaut du groupe</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Utiliser une séquence de remplissage automatique personnalisée :</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Titre de la fenêtre :</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Utiliser la séquence par défaut</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Définir une séquence personnalisée :</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Supprimer tout</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titre :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Confirmation :</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Gen.</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL :</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expiration</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Valeurs par défaut</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Notes :</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Ajouter un groupe</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Modifier le groupe</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Hériter du groupe parent (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expiration</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Remplissage automatique</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Utiliser la séquence de remplissage automatique par défaut du groupe parent</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Définir une séquence de remplissage automatique par défaut</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Utiliser l&apos;icône par défaut</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Utiliser une icône personnalisée</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Ajouter une icône personnalisée</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Supprimer une icône personnalisée</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les dossiers</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Choisir une image</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Impossible de supprimer l&apos;icône !</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Impossible de supprimer l&apos;icône. Toujours utilisée par %n objet(s).</numerusform><numerusform>Impossible de supprimer l&apos;icône. Toujours utilisée par %n objet(s).</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Créé le :</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Modifié le :</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Accédé le :</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid :</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Dernière modification</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Corbeille</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importer une base de données au format KeePass1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Impossible d&apos;ouvrir la base de données.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Impossible de lire le fichier-clé.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Ce n&apos;est pas une base de données KeePass.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Algorithme de chiffrement non supporté.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Version de base de données KeePass non supportée.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Racine</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Ce n&apos;est pas une base de données KeePass.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Version de base de données KeePass non supportée.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Mauvaise clé ou fichier de base de données corrompu.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Impossible de calculer la clé maître</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Le fichier sélectionné est une ancienne base de données pour KeePass 1 (.kdb).

Vous pouvez l&apos;importer en cliquant sur &quot;Base de données&quot; &gt; &quot;Importer une base de données KeePass 1&quot;.
Ceci est une migration à sens unique. Vous ne serez plus en mesure d&apos;ouvrir la base de données importée avec l&apos;ancienne version KeePassX version 0.4.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Erreur fatale lors des tests des fonctions cryptographiques.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - Erreur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Bases de données récentes</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Entrées</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Copier l&apos;attribut dans le presse-papier</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vue</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Ouvrir une base de données</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Enregistrer la base de données</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Fermer la base de données</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nouvelle base de données</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Ajouter une entrée</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Voir/Modifier l&apos;entrée</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Supprimer l&apos;entrée</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Ajouter un groupe</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Modifier le groupe</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Supprimer le groupe</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Enregistrer la base de données sous</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Modifier la clé maître</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Paramètres de la base de données</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importer une base de données KeePass 1</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Dupliquer l&apos;entrée</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Copier le nom d&apos;utilisateur dans le presse-papier</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Copier le mot de passe dans le presse-papier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Effectuer un remplissage automatique</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Ouvrir l&apos;URL</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Verrouiller les bases de données</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>Lecture seulement</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Basculer de fenêtre</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Copier le nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Copier le mot de passe</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Exporter au format CSV</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Réparer la base de données</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Base de données KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Sauvegarder la base de données réparée</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture de la base de données.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Longueur :</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Types de caractères</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Lettres majuscules</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Lettres minuscules</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Nombres</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Caractères spéciaux</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Exclure les caractères se ressemblant</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>S&apos;assurer que le mot de passe possède un caractère de chaque groupe</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Afficher les informations de version.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Afficher cette aide.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Option inconnue &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Options inconnues : %1.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Valeur manquante après &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Valeur inattendue après &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[options]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Utilisation : %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Options :</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Arguments :</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>Le fichier existant %1 n&apos;est pas accessible en écriture</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Écriture annulée par l&apos;application</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Écriture partielle. Partition pleine ?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Erreur interne zlib lors de la compression :</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Erreur d&apos;écriture sur le périphérique concerné :</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Erreur d&apos;ouverture du périphérique concerné :</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Erreur de lecture sur le périphérique concerné :</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Erreur interne zlib lors de la décompression :</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Le format gzip n&apos;est pas supporté dans cette version de zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Erreur interne zlib :</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Chercher :</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Sensible à la casse</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Groupe actif</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Groupe racine</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Paramètres de l&apos;application</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Se souvenir des dernières bases de données</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Ouvrir les bases de données précédentes au démarrage</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Sauvegarder automatiquement à la sortie</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Sauvegarder automatiquement après chaque modification</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Réduire lors de la copie dans le presse-papier</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Utiliser l&apos;icône de groupe à la création d&apos;une entrée</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Raccourci de remplissage automatique global</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Utiliser la correspondance entre le titre de l&apos;entrée et de la fenêtre pour le remplissage automatique global</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Afficher une icône dans la zone de notification</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Réduire la fenêtre vers la zone de notification lors de sa réduction</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Se rappeler les derniers fichiers-clés ouverts</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Vider le presse-papier après</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Verrouiller les bases de données après une inactivité de</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Afficher les mots de passe en clair par défaut</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Toujours demander avant d&apos;effectuer un remplissage automatique</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Déverrouiller la base de données</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Bienvenue !</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - Gestionnaire de mot de passe multi-plateforme</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>Nom de fichier de la base de données de mot de passe à ouvrir (*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>Chemin vers un fichier de configuration personnalisé</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>Fichier-clé de la base de données</translation>
    </message>
</context>
</TS>